==> haskell-yesod-core-1.6.8.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.8.1
id: yesod-core-1.6.8.1-ESCqu1i6WLR7yTVXNbPdk1
key: yesod-core-1.6.8.1-ESCqu1i6WLR7yTVXNbPdk1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: 936814ea0dab218f31835d2723795414
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-core-1.6.8.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-core-1.6.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/yesod-core-1.6.8.1
hs-libraries: HSyesod-core-1.6.8.1-ESCqu1i6WLR7yTVXNbPdk1
depends:
    aeson-1.4.1.0-BaRGy5iBSXU37DPvV6hbuH
    auto-update-0.1.4-JkSw4eg9S3X18mq8pcespF base-4.12.0.0
    blaze-html-0.9.1.1-W55jLnl9KQ9ftt8MpwW6m
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    clientsession-0.9.1.2-GkV4p6t0wfGDAWvKZmpcNm
    conduit-1.3.1-HILlOIEMKOZAyatAAf0ZaV
    conduit-extra-1.3.0-4OqcsCD2CphKm3eQ1xbl1F containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    fast-logger-2.4.11-8WvN8E6YOAF8XnRMV9Nh2c
    http-types-0.12.2-4Uk8pk84vvjHnZ7Fyj39KI
    monad-logger-0.3.30-9KIb0eFaURpCK2PIVBMe4m mtl-2.2.2
    parsec-3.1.13.0 path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-GG9Iz2OwOStJWdZMZJCJvR
    rio-0.1.5.0-6uNG7fOLgu12dQ4kY0MX4
    shakespeare-2.0.19-45FR3Hu89o45P2qMxT0j0X template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.5.0
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unliftio-0.2.8.1-AJAMW5z6oqwEQ5UmGImy9M
    unordered-containers-0.2.9.0-8YwmaeVELNEGd3AzVghTJw
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
    wai-3.2.1.2-KhIDUGreWowBHBI6gvcWLT
    wai-extra-3.0.24.3-G4XvI3bb6AbG32iDBZLkl6
    wai-logger-2.3.2-5ORtSsxYhUuKQInwLNOSwm
    warp-3.2.25-CwVxlQtIa7B4TVYyhMeL8L
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.8.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.8.1
id: yesod-core-1.6.8.1-AJMs24b5dGW2i6uZg4UqFk
key: yesod-core-1.6.8.1-AJMs24b5dGW2i6uZg4UqFk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: fc1699c6ea01e7a2bec25a6278e15870
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.2/site-local/yesod-core-1.6.8.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/yesod-core-1.6.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/yesod-core-1.6.8.1
hs-libraries: HSyesod-core-1.6.8.1-AJMs24b5dGW2i6uZg4UqFk
depends:
    aeson-1.4.1.0-LhGJkSbQXa4Bc1ggOsS4Ag
    auto-update-0.1.4-JkSw4eg9S3X18mq8pcespF base-4.12.0.0
    blaze-html-0.9.1.1-BgfYHwfc8MB4VF6u8ZvMhm
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    cereal-0.5.7.0-GJYlaDDl5qNLbZMZyr0ENN
    clientsession-0.9.1.2-Hxfv7Th7g5Qi90sOd2dPj
    conduit-1.3.1-7nGkXAHpHom9EMlfdTpJwN
    conduit-extra-1.3.0-1UBKzWne4IL48XFzboel3z containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    fast-logger-2.4.11-7C28CYvTEftDJP7j0xMmJ7
    http-types-0.12.2-JL0Kcsx8GXu5DLLC6mrxVW
    monad-logger-0.3.30-CybFzLBMKB2Y0A69xWTbJ mtl-2.2.2 parsec-3.1.13.0
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-841yAQBgNwO7J9O4S3A6Ce
    rio-0.1.5.0-6U4ID6mxBrgDsEZFD83MUY
    shakespeare-2.0.19-GCvuNqvgIiJaNb9V3QruS template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.5.0
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unliftio-0.2.8.1-8cf9OB6I5QG3W3ZsuaQcva
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
    wai-3.2.1.2-BFXYuBVtQneLt4oXIwpyWq
    wai-extra-3.0.24.3-CBiAxxd9hWfChjfZ27hN3q
    wai-logger-2.3.2-7mzT2mDNVaTC0Vl2kjPcMj
    warp-3.2.25-SS2x5ocVoI31dLKz5kz13
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
